<p align="center">
  <a href="https://github.com/Drelf2018/submitter/">
    <img src="https://user-images.githubusercontent.com/41439182/220989932-10aeb2f4-9526-4ec5-9991-b5960041be1f.png" height="200" alt="submitter">
  </a>
</p>

<div align="center">

# submitter

_✨ 基于 [webhook](https://github.com/Drelf2018/webhook) 的博文提交器 ✨_  

</div>

<p align="center">
  <a href="https://qr.api.cli.im/newqr/create?data=%E6%B2%A1%E5%86%99%E5%93%88%E5%93%88%2F&kid=cliim&key=617ba1f8e3ba8cd67739f905dc894b78">文档</a>
  ·
  <a href="https://pypi.org/project/post-submitter/">下载</a>
  ·
  <a href="https://github.com/Drelf2018/submitter/tree/main/tests.py">开始使用</a>
</p>

### 教程

我没写 ～(∠・ω< )